@@ -1,11 +1,12 @@
 # pylint: disable=invalid-name
 import platform
+
 from UnleashClient.strategies.Strategy import Strategy
 
 
 class ApplicationHostname(Strategy):
     def load_provisioning(self) -> list:
-        return [x.strip() for x in self.parameters["hostNames"].split(',')]
+        return [x.strip() for x in self.parameters["hostNames"].split(",")]
 
     def apply(self, context: dict = None) -> bool:
         """
