@@ -1,5 +1,6 @@
 # pylint: disable=invalid-name
 import ipaddress
+
 from UnleashClient.strategies.Strategy import Strategy
 from UnleashClient.utils import LOGGER
 
@@ -8,17 +9,24 @@ class RemoteAddress(Strategy):
     def load_provisioning(self) -> list:
         parsed_ips = []
 
-        for address in self.parameters["IPs"].split(','):
-
+        for address in self.parameters["IPs"].split(","):
             if "/" in address:
                 try:
                     parsed_ips.append(ipaddress.ip_network(address.strip(), strict=True))  # type: ignore
-                except (ipaddress.AddressValueError, ipaddress.NetmaskValueError, ValueError) as parsing_error:
+                except (
+                    ipaddress.AddressValueError,
+                    ipaddress.NetmaskValueError,
+                    ValueError,
+                ) as parsing_error:
                     LOGGER.warning("Error parsing IP range: %s", parsing_error)
             else:
                 try:
                     parsed_ips.append(ipaddress.ip_address(address.strip()))  # type: ignore
-                except (ipaddress.AddressValueError, ipaddress.NetmaskValueError, ValueError) as parsing_error:
+                except (
+                    ipaddress.AddressValueError,
+                    ipaddress.NetmaskValueError,
+                    ValueError,
+                ) as parsing_error:
                     LOGGER.warning("Error parsing IP : %s", parsing_error)
 
         return parsed_ips
@@ -33,19 +41,28 @@ class RemoteAddress(Strategy):
 
         try:
             context_ip = ipaddress.ip_address(context["remoteAddress"])
-        except (ipaddress.AddressValueError, ipaddress.NetmaskValueError, ValueError) as parsing_error:
+        except (
+            ipaddress.AddressValueError,
+            ipaddress.NetmaskValueError,
+            ValueError,
+        ) as parsing_error:
             LOGGER.warning("Error parsing IP : %s", parsing_error)
             context_ip = None
 
         if context_ip:
-            for addr_or_range in [value for value in self.parsed_provisioning if value.version == context_ip.version]:
-                if isinstance(addr_or_range, (ipaddress.IPv4Address, ipaddress.IPv6Address)):
+            for addr_or_range in [
+                value
+                for value in self.parsed_provisioning
+                if value.version == context_ip.version
+            ]:
+                if isinstance(
+                    addr_or_range, (ipaddress.IPv4Address, ipaddress.IPv6Address)
+                ):
                     if context_ip == addr_or_range:
                         return_value = True
                         break
-                else:
-                    if context_ip in addr_or_range:
-                        return_value = True
-                        break
+                elif context_ip in addr_or_range:  # noqa: PLR5501
+                    return_value = True
+                    break
 
         return return_value
