@@ -1,7 +1,16 @@
 # pylint: disable=invalid-name,dangerous-default-value
-from typing import Iterator
 import warnings
+from dataclasses import dataclass
+from typing import Iterator, Optional
+
 from UnleashClient.constraints import Constraint
+from UnleashClient.variants import Variants
+
+
+@dataclass
+class EvaluationResult:
+    enabled: bool
+    variant: Optional[dict]
 
 
 class Strategy:
@@ -14,17 +23,21 @@ class Strategy:
     - ``apply()`` - Your feature provisioning
 
     :param constraints: List of 'constraints' objects derived from strategy section (...from feature section) of `/api/clients/features` Unleash server response.
+    :param variants: List of 'variant' objects derived from strategy section (...from feature section) of `/api/clients/features` Unleash server response.
     :param parameters: The 'parameter' objects from the strategy section (...from feature section) of `/api/clients/features` Unleash server response.
     """
 
-    def __init__(self,
-                 constraints: list = [],
-                 parameters: dict = {},
-                 segment_ids: list = None,
-                 global_segments: dict = None
-                 ) -> None:
+    def __init__(
+        self,
+        constraints: list = [],
+        parameters: dict = {},
+        segment_ids: list = None,
+        global_segments: dict = None,
+        variants: list = None,
+    ) -> None:
         self.parameters = parameters
         self.constraints = constraints
+        self.variants = variants or []
         self.segment_ids = segment_ids or []
         self.global_segments = global_segments or {}
         self.parsed_provisioning = self.load_provisioning()
@@ -32,7 +45,7 @@ class Strategy:
     def __call__(self, context: dict = None):
         warnings.warn(
             "unleash-client-python v3.x.x requires overriding the execute() method instead of the __call__() method.",
-            DeprecationWarning
+            DeprecationWarning,
         )
 
     def execute(self, context: dict = None) -> bool:
@@ -54,6 +67,15 @@ class Strategy:
 
         return flag_state
 
+    def get_result(self, context) -> EvaluationResult:
+        enabled = self.execute(context)
+        variant = None
+        if enabled:
+            variant = self.parsed_variants.get_variant(context, enabled)
+
+        result = EvaluationResult(enabled, variant)
+        return result
+
     @property
     def parsed_constraints(self) -> Iterator[Constraint]:
         for constraint_dict in self.constraints:
@@ -64,6 +86,14 @@ class Strategy:
             for constraint in segment["constraints"]:
                 yield Constraint(constraint_dict=constraint)
 
+    @property
+    def parsed_variants(self) -> Variants:
+        return Variants(
+            variants_list=self.variants,
+            group_id=self.parameters.get("groupId"),
+            is_feature_variants=False,
+        )
+
     def load_provisioning(self) -> list:  # pylint: disable=no-self-use
         """
         Loads strategy provisioning from Unleash feature flag configuration.
@@ -72,7 +102,9 @@ class Strategy:
         """
         return []
 
-    def apply(self, context: dict = None) -> bool:  # pylint: disable=unused-argument,no-self-use
+    def apply(
+        self, context: dict = None
+    ) -> bool:  # pylint: disable=unused-argument,no-self-use
         """
         Strategy implementation.
 
