@@ -10,14 +10,15 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 
-import UnleashClient
 from importlib_metadata import version
 
+import UnleashClient  # noqa: F401
+
 # -- Project information -----------------------------------------------------
 
-project = 'unleash-client-python'
-copyright = '2022 Unleash'
-author = 'Ivan Lee'
+project = "unleash-client-python"
+copyright = "2022 Unleash"
+author = "Ivan Lee"
 version = version("UnleashClient")
 
 
@@ -32,36 +33,38 @@ extensions = [
     "sphinx.ext.autosummary",
     "sphinx.ext.githubpages",
     "m2r2",
-    "enum_tools.autoenum"
+    "enum_tools.autoenum",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
-source_suffix = ['.rst', '.md']
+source_suffix = [".rst", ".md"]
 
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'sphinx_rtd_theme'
+html_theme = "sphinx_rtd_theme"
 
-html_sidebars = { '**': ['globaltoc.html', 'relations.html', 'sourcelink.html', 'searchbox.html'] }
+html_sidebars = {
+    "**": ["globaltoc.html", "relations.html", "sourcelink.html", "searchbox.html"]
+}
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = ["_static"]
 
 html_context = {
-  'display_github': True,
-  'github_user': 'unleash',
-  'github_repo': 'unleash-client-python',
-  'github_version': 'main/docs/',
+    "display_github": True,
+    "github_user": "unleash",
+    "github_repo": "unleash-client-python",
+    "github_version": "main/docs/",
 }
