@@ -1,15 +1,16 @@
 import responses
-from UnleashClient import UnleashClient
-from UnleashClient.strategies import Strategy
-from tests.utilities.testing_constants import URL, APP_NAME
+
 from tests.utilities.mocks import MOCK_CUSTOM_STRATEGY
 from tests.utilities.old_code.StrategyV2 import StrategyOldV2
-from UnleashClient.constants import REGISTER_URL, FEATURES_URL, METRICS_URL
+from tests.utilities.testing_constants import APP_NAME, URL
+from UnleashClient import UnleashClient
+from UnleashClient.constants import FEATURES_URL, METRICS_URL, REGISTER_URL
+from UnleashClient.strategies import Strategy
 
 
 class CatTest(Strategy):
     def load_provisioning(self) -> list:
-        return [x.strip() for x in self.parameters["sound"].split(',')]
+        return [x.strip() for x in self.parameters["sound"].split(",")]
 
     def apply(self, context: dict = None) -> bool:
         """
@@ -27,7 +28,7 @@ class CatTest(Strategy):
 
 class DogTest(StrategyOldV2):
     def load_provisioning(self) -> list:
-        return [x.strip() for x in self.parameters["sound"].split(',')]
+        return [x.strip() for x in self.parameters["sound"].split(",")]
 
     def _call_(self, context: dict = None) -> bool:
         """
@@ -46,19 +47,16 @@ class DogTest(StrategyOldV2):
 @responses.activate
 def test_uc_customstrategy_happypath(recwarn):
     responses.add(responses.POST, URL + REGISTER_URL, json={}, status=202)
-    responses.add(responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200)
+    responses.add(
+        responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200
+    )
     responses.add(responses.POST, URL + METRICS_URL, json={}, status=202)
 
-    custom_strategies_dict = {
-        "amIACat": CatTest,
-        "amIADog": DogTest
-    }
+    custom_strategies_dict = {"amIACat": CatTest, "amIADog": DogTest}
 
     unleash_client = UnleashClient(
-        URL,
-        APP_NAME,
-        environment="prod",
-        custom_strategies=custom_strategies_dict)
+        URL, APP_NAME, environment="prod", custom_strategies=custom_strategies_dict
+    )
 
     unleash_client.initialize_client()
 
@@ -74,19 +72,16 @@ def test_uc_customstrategy_happypath(recwarn):
 @responses.activate
 def test_uc_customstrategy_depredationwarning():
     responses.add(responses.POST, URL + REGISTER_URL, json={}, status=202)
-    responses.add(responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200)
+    responses.add(
+        responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200
+    )
     responses.add(responses.POST, URL + METRICS_URL, json={}, status=202)
 
-    custom_strategies_dict = {
-        "amIACat": CatTest,
-        "amIADog": DogTest
-    }
+    custom_strategies_dict = {"amIACat": CatTest, "amIADog": DogTest}
 
     unleash_client = UnleashClient(
-        URL,
-        APP_NAME,
-        environment="prod",
-        custom_strategies=custom_strategies_dict)
+        URL, APP_NAME, environment="prod", custom_strategies=custom_strategies_dict
+    )
 
     unleash_client.initialize_client()
 
@@ -97,19 +92,16 @@ def test_uc_customstrategy_depredationwarning():
 @responses.activate
 def test_uc_customstrategy_safemulti():
     responses.add(responses.POST, URL + REGISTER_URL, json={}, status=202)
-    responses.add(responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200)
+    responses.add(
+        responses.GET, URL + FEATURES_URL, json=MOCK_CUSTOM_STRATEGY, status=200
+    )
     responses.add(responses.POST, URL + METRICS_URL, json={}, status=202)
 
-    custom_strategies_dict = {
-        "amIACat": CatTest,
-        "amIADog": DogTest
-    }
+    custom_strategies_dict = {"amIACat": CatTest, "amIADog": DogTest}
 
     unleash_client = UnleashClient(
-        URL,
-        APP_NAME,
-        environment="prod",
-        custom_strategies=custom_strategies_dict)
+        URL, APP_NAME, environment="prod", custom_strategies=custom_strategies_dict
+    )
 
     unleash_client.initialize_client()
 
