@@ -1,11 +1,12 @@
 import copy
-from UnleashClient.loader import load_features
-from UnleashClient.features import Feature
-from UnleashClient.strategies import GradualRolloutUserId, FlexibleRollout, UserWithId
-from UnleashClient.variants import Variants
-from UnleashClient.constants import FEATURES_URL, FAILED_STRATEGIES
+
 from tests.utilities.mocks import MOCK_ALL_FEATURES
 from tests.utilities.testing_constants import DEFAULT_STRATEGY_MAPPING
+from UnleashClient.constants import FAILED_STRATEGIES, FEATURES_URL
+from UnleashClient.features import Feature
+from UnleashClient.loader import load_features
+from UnleashClient.strategies import FlexibleRollout, GradualRolloutUserId, UserWithId
+from UnleashClient.variants import Variants
 
 
 def test_loader_initialization(cache_full):  # noqa: F811
@@ -16,10 +17,12 @@ def test_loader_initialization(cache_full):  # noqa: F811
     # Tests
     load_features(temp_cache, in_memory_features, DEFAULT_STRATEGY_MAPPING)
     assert isinstance(in_memory_features["GradualRolloutUserID"], Feature)
-    assert isinstance(in_memory_features["GradualRolloutUserID"].strategies[0], GradualRolloutUserId)
+    assert isinstance(
+        in_memory_features["GradualRolloutUserID"].strategies[0], GradualRolloutUserId
+    )
 
     for feature_name in in_memory_features.keys():
-        if feature_name == 'Garbage':  # Don't check purposely invalid strategy.
+        if feature_name == "Garbage":  # Don't check purposely invalid strategy.
             break
 
         feature = in_memory_features[feature_name]
@@ -53,7 +56,12 @@ def test_loader_refresh_strategies(cache_full):  # noqa: F811
 
     load_features(temp_cache, in_memory_features, DEFAULT_STRATEGY_MAPPING)
 
-    assert in_memory_features["GradualRolloutUserID"].strategies[0].parameters["percentage"] == 60
+    assert (
+        in_memory_features["GradualRolloutUserID"]
+        .strategies[0]
+        .parameters["percentage"]
+        == 60
+    )
     assert len(temp_cache.get(FAILED_STRATEGIES)) == 1
 
 
@@ -92,4 +100,4 @@ def test_loader_segments(cache_segments):
     load_features(temp_cache, in_memory_features, DEFAULT_STRATEGY_MAPPING)
     feature = in_memory_features["Test"]
     loaded_constraints = list(feature.strategies[0].parsed_constraints)
-    assert(len(loaded_constraints) == 2)
+    assert len(loaded_constraints) == 2
