@@ -2,7 +2,7 @@ import mimesis
 
 
 def generate_context():
-    return {"userId": mimesis.Person('en').email()}
+    return {"userId": mimesis.Person("en").email()}
 
 
 def generate_email_list(num: int) -> (str, dict):
@@ -12,12 +12,12 @@ def generate_email_list(num: int) -> (str, dict):
     :param num:
     :return:
     """
-    first_email = mimesis.Person('en').email()
+    first_email = mimesis.Person("en").email()
     email_list_string = first_email
 
     context = {"userId": first_email}
 
     for _ in range(num - 1):
-        email_list_string += "," + mimesis.Person('en').email()
+        email_list_string += "," + mimesis.Person("en").email()
 
     return (email_list_string, context)
