@@ -8,57 +8,37 @@ MOCK_CUSTOM_STRATEGY = {
             "strategies": [
                 {
                     "name": "amIACat",
-                    "parameters": {
-                        "sound": "meow,nyaa"
-                    },
+                    "parameters": {"sound": "meow,nyaa"},
                     "constraints": [
                         {
                             "contextName": "environment",
                             "operator": "IN",
-                            "values": [
-                                "staging",
-                                "prod"
-                            ]
+                            "values": ["staging", "prod"],
                         }
-                    ]
+                    ],
                 }
             ],
             "createdAt": "2018-10-13T10:15:29.009Z",
-            "impressionData": False
+            "impressionData": False,
         },
         {
             "name": "CustomToggleWarning",
             "description": "CustomToggle Warning Test",
             "enabled": True,
-            "strategies": [
-                {
-                    "name": "amIADog",
-                    "parameters": {
-                        "sound": "arf,bark"
-                    }
-                }
-            ],
+            "strategies": [{"name": "amIADog", "parameters": {"sound": "arf,bark"}}],
             "createdAt": "2018-10-13T10:15:29.009Z",
-            "impressionData": False
+            "impressionData": False,
         },
         {
             "name": "CustomToggleWarningMultiStrat",
             "description": "CustomToggle Warning Test",
             "enabled": True,
             "strategies": [
-                {
-                    "name": "amIADog",
-                    "parameters": {
-                        "sound": "arf,bark"
-                    }
-                },
-                {
-                    "name": "default",
-                    "parameters": {}
-                }
+                {"name": "amIADog", "parameters": {"sound": "arf,bark"}},
+                {"name": "default", "parameters": {}},
             ],
             "createdAt": "2018-10-13T10:15:29.009Z",
-            "impressionData": False
+            "impressionData": False,
         },
         {
             "name": "UserWithId",
@@ -69,11 +49,11 @@ MOCK_CUSTOM_STRATEGY = {
                     "name": "userWithId",
                     "parameters": {
                         "userIds": "meep@meep.com,test@test.com,ivan@ivan.com"
-                    }
+                    },
                 }
             ],
             "createdAt": "2018-10-11T09:33:51.171Z",
-            "impressionData": False
-        }
-    ]
+            "impressionData": False,
+        },
+    ],
 }
