@@ -1,6 +1,14 @@
-from UnleashClient.strategies import ApplicationHostname, Default, GradualRolloutRandom, \
-    GradualRolloutSessionId, GradualRolloutUserId, UserWithId, RemoteAddress, FlexibleRollout
 from UnleashClient.constants import FEATURES_URL
+from UnleashClient.strategies import (
+    ApplicationHostname,
+    Default,
+    FlexibleRollout,
+    GradualRolloutRandom,
+    GradualRolloutSessionId,
+    GradualRolloutUserId,
+    RemoteAddress,
+    UserWithId,
+)
 
 # General configs
 APP_NAME = "pytest"
@@ -14,6 +22,8 @@ DISABLE_METRICS = True
 DISABLE_REGISTRATION = True
 CUSTOM_HEADERS = {"name": "My random header."}
 CUSTOM_OPTIONS = {"verify": False}
+REQUEST_TIMEOUT = 30
+REQUEST_RETRIES = 3
 
 # URLs
 URL = "http://localhost:4242/api"
@@ -21,8 +31,10 @@ INTEGRATION_URL = "http://localhost:4242/api"
 PROJECT_URL = f"{URL}{FEATURES_URL}?project=ivan"
 
 # Constants
-IP_LIST = "69.208.0.0/29,70.208.1.1,2001:db8:1234::/48,2002:db8:1234:0000:0000:0000:0000:0001"
-PROJECT_NAME = 'ivan'
+IP_LIST = (
+    "69.208.0.0/29,70.208.1.1,2001:db8:1234::/48,2002:db8:1234:0000:0000:0000:0000:0001"
+)
+PROJECT_NAME = "ivan"
 ETAG_VALUE = 'W/"730-v0ozrE11zfZK13j7rQ5PxkXfjYQ"'
 
 # Mapping
@@ -34,5 +46,5 @@ DEFAULT_STRATEGY_MAPPING = {
     "gradualRolloutUserId": GradualRolloutUserId,
     "remoteAddress": RemoteAddress,
     "userWithId": UserWithId,
-    "flexibleRollout": FlexibleRollout
+    "flexibleRollout": FlexibleRollout,
 }
